package com.gic.auth.web.controller;

import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.auth.dto.ResourceDTO;
import com.gic.auth.service.ResourceApiService;
import com.gic.auth.web.qo.PageQO;
import com.gic.auth.web.qo.ResourceQO;
import com.gic.auth.web.vo.ResourceVO;
import com.gic.auth.web.vo.StoreResouceVO;
import com.gic.commons.util.EntityUtil;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.enterprise.response.EnterpriseRestResponse;
import com.gic.enterprise.utils.ResultControllerUtils;
import com.gic.enterprise.utils.UserDetailUtils;
import com.gic.store.dto.StoreWidgetDTO;
import com.gic.store.service.StoreWidgetApiService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 *
 * @Description:
 * @author zhiwj
 * @date 2019/8/29 9:09
 */
@RestController
public class ResourceController {

    @Autowired
    private ResourceApiService resourceApiService;
    @Autowired
    private StoreWidgetApiService storeWidgetApiService;

    @RequestMapping("/save-resource")
    public RestResponse saveResource(ResourceQO resourceQO) {
        ResourceDTO resourceDTO = EntityUtil.changeEntityByOrika(ResourceDTO.class, resourceQO);
        resourceDTO.setEnterpriseId(UserDetailUtils.getUserDetail().getEnterpriseId());
        StoreWidgetDTO storeWidgetDTO = new StoreWidgetDTO();
        storeWidgetDTO.setAuthMode(resourceQO.getStoreResouce().getAuthMode());
        storeWidgetDTO.setSearchParam(resourceQO.getStoreResouce().getSearchParam());
        storeWidgetDTO.setStoreWidgetId(resourceQO.getStoreResouce().getStoreResourceId());
        storeWidgetDTO.setWriteBackParam(resourceQO.getStoreResouce().getWriteBackParam());
        ServiceResponse<Integer> storeWidgetResponse = this.storeWidgetApiService.saveAuthStoreWidget(storeWidgetDTO);
        if(storeWidgetResponse.isSuccess()){
            resourceDTO.setStoreResource(storeWidgetResponse.getResult().longValue());
            ServiceResponse<Integer> response = resourceApiService.saveOrUpdateResource(resourceDTO);
            if(response.isSuccess()){
                return RestResponse.success(response.getResult());
            }
            return EnterpriseRestResponse.failure(response);
        }
        return EnterpriseRestResponse.failure(storeWidgetResponse);
    }

    @RequestMapping("/del-resource")
    public RestResponse delResource(Integer resourceId) {
        ServiceResponse<Integer> serviceResponse = resourceApiService.delResource(resourceId);
        return ResultControllerUtils.commonResult(serviceResponse);
    }

    @RequestMapping("/list-resource")
    public RestResponse listResource(ResourceQO resourceQO, PageQO pageQO) {
        ResourceDTO resourceDTO = EntityUtil.changeEntityByOrika(ResourceDTO.class, resourceQO);
        resourceDTO.setEnterpriseId(UserDetailUtils.getUserDetail().getEnterpriseId());
        ServiceResponse<Page<ResourceDTO>> serviceResponse = resourceApiService.listResource(resourceDTO, pageQO.getCurrentPage(), pageQO.getPageSize());
        return ResultControllerUtils.commonResult(serviceResponse);
    }

    @RequestMapping("/get-resource")
    public RestResponse getResource(Integer resourceId){
        ServiceResponse<ResourceDTO> response = resourceApiService.getResource(resourceId);
        if (response.isSuccess()) {
            ResourceVO vo = EntityUtil.changeEntityByJSON(ResourceVO.class, response.getResult());
            ServiceResponse<StoreWidgetDTO> storeWidget = this.storeWidgetApiService.getStoreWidget(response.getResult().getStoreResource().intValue());
            if(storeWidget.isSuccess()) {
                if (storeWidget.getResult() != null) {
                    StoreResouceVO storeResouceVO = new StoreResouceVO();
                    storeResouceVO.setStoreResourceId(response.getResult().getStoreResource().intValue());
                    storeResouceVO.setAuthMode(storeWidget.getResult().getAuthMode());
                    storeResouceVO.setSearchParam(storeWidget.getResult().getSearchParam());
                    storeResouceVO.setWriteBackParam(storeWidget.getResult().getWriteBackParam());
                    vo.setStoreResouce(storeResouceVO);
                }
            }
            return RestResponse.success(vo);
        }
        return EnterpriseRestResponse.failure(response);
    }

}
